@@ -64,7 +64,7 @@ class ClientResponseError(ClientError):
         code: Optional[int] = None,
         status: Optional[int] = None,
         message: str = "",
-        headers: Optional[LooseHeaders] = None
+        headers: Optional[LooseHeaders] = None,
     ) -> None:
         self.request_info = request_info
         if code is not None:
@@ -90,21 +90,21 @@ class ClientResponseError(ClientError):
         self.args = (request_info, history)
 
     def __str__(self) -> str:
-        return "%s, message=%r, url=%r" % (
+        return "{}, message={!r}, url={!r}".format(
             self.status,
             self.message,
             self.request_info.real_url,
         )
 
     def __repr__(self) -> str:
-        args = "%r, %r" % (self.request_info, self.history)
+        args = f"{self.request_info!r}, {self.history!r}"
         if self.status != 0:
-            args += ", status=%r" % (self.status,)
+            args += f", status={self.status!r}"
         if self.message != "":
-            args += ", message=%r" % (self.message,)
+            args += f", message={self.message!r}"
         if self.headers is not None:
-            args += ", headers=%r" % (self.headers,)
-        return "%s(%s)" % (type(self).__name__, args)
+            args += f", headers={self.headers!r}"
+        return "{}({})".format(type(self).__name__, args)
 
     @property
     def code(self) -> int:
@@ -257,7 +257,7 @@ class InvalidURL(ClientError, ValueError):
         return self.args[0]
 
     def __repr__(self) -> str:
-        return "<{} {}>".format(self.__class__.__name__, self.url)
+        return f"<{self.__class__.__name__} {self.url}>"
 
 
 class ClientSSLError(ClientConnectorError):
