@@ -121,7 +121,7 @@ class PayloadRegistry:
         elif order is Order.try_last:
             self._last.append((factory, type))
         else:
-            raise ValueError("Unsupported order {!r}".format(order))
+            raise ValueError(f"Unsupported order {order!r}")
 
 
 class Payload(ABC):
@@ -138,7 +138,7 @@ class Payload(ABC):
         content_type: Optional[str] = sentinel,
         filename: Optional[str] = None,
         encoding: Optional[str] = None,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
         self._encoding = encoding
         self._filename = filename
@@ -246,7 +246,7 @@ class StringPayload(BytesPayload):
         *args: Any,
         encoding: Optional[str] = None,
         content_type: Optional[str] = None,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
 
         if encoding is None:
@@ -306,7 +306,7 @@ class TextIOPayload(IOBasePayload):
         *args: Any,
         encoding: Optional[str] = None,
         content_type: Optional[str] = None,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
 
         if encoding is None:
@@ -374,7 +374,7 @@ class JsonPayload(BytesPayload):
         content_type: str = "application/json",
         dumps: JSONEncoder = json.dumps,
         *args: Any,
-        **kwargs: Any
+        **kwargs: Any,
     ) -> None:
 
         super().__init__(
