@@ -66,7 +66,7 @@ class FileField:
 _TCHAR = string.digits + string.ascii_letters + r"!#$%&'*+.^_`|~-"
 # '-' at the end to prevent interpretation as range in a char class
 
-_TOKEN = r"[{tchar}]+".format(tchar=_TCHAR)
+_TOKEN = fr"[{_TCHAR}]+"
 
 _QDTEXT = r"[{}]".format(
     r"".join(chr(c) for c in (0x09, 0x20, 0x21) + tuple(range(0x23, 0x7F)))
@@ -139,7 +139,7 @@ class BaseRequest(MutableMapping[str, Any], HeadersMixin):
         state: Optional[Dict[str, Any]] = None,
         scheme: Optional[str] = None,
         host: Optional[str] = None,
-        remote: Optional[str] = None
+        remote: Optional[str] = None,
     ) -> None:
         if state is None:
             state = {}
@@ -183,7 +183,7 @@ class BaseRequest(MutableMapping[str, Any], HeadersMixin):
         headers: LooseHeaders = sentinel,
         scheme: str = sentinel,
         host: str = sentinel,
-        remote: str = sentinel
+        remote: str = sentinel,
     ) -> "BaseRequest":
         """Clone itself with replacement some attributes.
 
@@ -229,7 +229,7 @@ class BaseRequest(MutableMapping[str, Any], HeadersMixin):
             self._loop,
             client_max_size=self._client_max_size,
             state=self._state.copy(),
-            **kwargs
+            **kwargs,
         )
 
     @property
@@ -778,7 +778,7 @@ class Request(BaseRequest):
         headers: LooseHeaders = sentinel,
         scheme: str = sentinel,
         host: str = sentinel,
-        remote: str = sentinel
+        remote: str = sentinel,
     ) -> "Request":
         ret = super().clone(
             method=method,
