@@ -12,14 +12,15 @@ needs (i.e. ``-H``, ``-P`` & ``entry-func``) and passes on any additional
 arguments to the `cli_app:init` function for processing.
 """
 
-from aiohttp.web import Application, Response
 from argparse import ArgumentParser
 
+from aiohttp import web
+
 
 def display_message(req):
     args = req.app["args"]
     text = "\n".join([args.message] * args.repeat)
-    return Response(text=text)
+    return web.Response(text=text)
 
 
 def init(argv):
@@ -28,27 +29,22 @@ def init(argv):
     )
 
     # Positional argument
-    arg_parser.add_argument(
-        "message",
-        help="message to print"
-    )
+    arg_parser.add_argument("message", help="message to print")
 
     # Optional argument
     arg_parser.add_argument(
-        "--repeat",
-        help="number of times to repeat message", type=int, default="1"
+        "--repeat", help="number of times to repeat message", type=int, default="1"
     )
 
     # Avoid conflict with -h from `aiohttp.web` CLI parser
     arg_parser.add_argument(
-        "--app-help",
-        help="show this message and exit", action="help"
+        "--app-help", help="show this message and exit", action="help"
     )
 
     args = arg_parser.parse_args(argv)
 
-    app = Application()
+    app = web.Application()
     app["args"] = args
-    app.router.add_route('GET', '/', display_message)
+    app.router.add_get("/", display_message)
 
     return app
